linked_list

package
v0.0.0-...-c3db47b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2024 License: MIT Imports: 1 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LinkedList

type LinkedList struct {
	// contains filtered or unexported fields
}

func (*LinkedList) DataAt

func (ll *LinkedList) DataAt(index int) (int, bool)

func (*LinkedList) DeleteAt

func (ll *LinkedList) DeleteAt(index int) (int, bool)

DeleteAt returns the deleted data at the index and whether the index is valid or not

func (*LinkedList) Find

func (ll *LinkedList) Find(dataToFind int) (int, bool)

Find returns the index of the dataToFind and whether it is present in list or not.

func (*LinkedList) Head

func (ll *LinkedList) Head() *Node

func (*LinkedList) InsertAt

func (ll *LinkedList) InsertAt(dt, index int) bool

func (*LinkedList) Len

func (ll *LinkedList) Len() int

func (*LinkedList) Print

func (ll *LinkedList) Print() string

func (*LinkedList) Tail

func (ll *LinkedList) Tail() *Node

type Node

type Node struct {
	// contains filtered or unexported fields
}

func ReverseOne

func ReverseOne(head *Node) *Node

Jump to