Documentation
¶
Index ¶
- type LinkedList
- func (ll *LinkedList) DataAt(index int) (int, bool)
- func (ll *LinkedList) DeleteAt(index int) (int, bool)
- func (ll *LinkedList) Find(dataToFind int) (int, bool)
- func (ll *LinkedList) Head() *Node
- func (ll *LinkedList) InsertAt(dt, index int) bool
- func (ll *LinkedList) Len() int
- func (ll *LinkedList) Print() string
- func (ll *LinkedList) Tail() *Node
- type Node
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LinkedList ¶
type LinkedList struct {
// contains filtered or unexported fields
}
func (*LinkedList) DeleteAt ¶
func (ll *LinkedList) DeleteAt(index int) (int, bool)
DeleteAt returns the deleted data at the index and whether the index is valid or not
func (*LinkedList) Find ¶
func (ll *LinkedList) Find(dataToFind int) (int, bool)
Find returns the index of the dataToFind and whether it is present in list or not.
func (*LinkedList) Head ¶
func (ll *LinkedList) Head() *Node
func (*LinkedList) InsertAt ¶
func (ll *LinkedList) InsertAt(dt, index int) bool
func (*LinkedList) Len ¶
func (ll *LinkedList) Len() int
func (*LinkedList) Print ¶
func (ll *LinkedList) Print() string
func (*LinkedList) Tail ¶
func (ll *LinkedList) Tail() *Node
Click to show internal directories.
Click to hide internal directories.